@@ -3,7 +3,7 @@ setClass("status",
                         text="character",
                         favorited="logical",
                         replyToSN="character",
-                        created="character",
+                        created="POSIXct",
                         truncated="logical",
                         replyToSID="numeric",
                         id="numeric",
@@ -13,12 +13,12 @@ setClass("status",
                         )
          )
 
-setMethod("text", signature="status", function(x, ...) {
-    x@text
+setMethod("show", signature="status", function(object) {
+    print(paste(screenName(object), object@text, sep=": "))
 })
 
-setMethod("show", signature="status", function(object) {
-    print(paste(screenName(object), text(object), sep=": "))
+setMethod("statusText", signature="status", function(object) {
+    object@text
 })
 
 setMethod("favorited", signature="status", function(object, ...) {
@@ -66,7 +66,7 @@ setClass("user",
                         friendsCount="numeric",
                         url="character",
                         name="character",
-                        created="character",
+                        created="POSIXct",
                         protected="logical",
                         verified="logical",
                         screenName="character",
@@ -140,58 +140,3 @@ setMethod("lastStatus", signature="user", function(object, ...) {
     object@lastStatus
 })
 
-setClass("directMessage",
-         representation(
-                        text="character",
-                        recipientSN="character",
-                        created="character",
-                        recipientID="numeric",
-                        sender="user",
-                        recipient="user",
-                        senderID="numeric",
-                        id="numeric",
-                        senderSN="character"
-                        )
-         )
-
-setMethod("show", signature="directMessage", function(object) {
-    print(paste(screenName(object@sender), "->",
-                screenName(object@recipient),  ":",
-                object@text, sep=""))
-})
-
-setMethod("text", signature="directMessage", function(x) {
-    x@text
-})
-
-setMethod("recipientSN", signature="directMessage", function(object) {
-    object@recipientSN
-})
-
-setMethod("created", signature="directMessage", function(object) {
-    object@created
-})
-
-setMethod("recipientID", signature="directMessage", function(object) {
-    object@recipientID
-})
-
-setMethod("sender", signature="directMessage", function(object) {
-    object@sender
-})
-
-setMethod("recipient", signature="directMessage", function(object) {
-    object@recipient
-})
-
-setMethod("senderID", signature="directMessage", function(object) {
-    object@senderID
-})
-
-setMethod("id", signature="directMessage", function(object) {
-    object@id
-})
-
-setMethod("senderSN", signature="directMessage", function(object) {
-    object@senderSN
-})
